@@ -1,5 +1,5 @@
 __author__ = 'Andrea De Marco <24erre@gmail.com>'
-__version__ = '2.4.3'
+__version__ = '2.7.0'
 __classifiers__ = [
     'Development Status :: 5 - Production/Stable',
     'Intended Audience :: Developers',
@@ -8,6 +8,8 @@ __classifiers__ = [
     'Programming Language :: Python :: 2.6',
     'Programming Language :: Python :: 2.7',
     'Programming Language :: Python :: 3.3',
+    'Programming Language :: Python :: 3.4',
+    'Programming Language :: Python :: 3.5',
     'Topic :: Internet :: WWW/HTTP',
     'Topic :: Software Development :: Libraries',
 ]
@@ -47,15 +49,18 @@ def parse_args():
     parser = argparse.ArgumentParser(prog='coveralls')
     parser.add_argument('--coveralls_url', '-u', help='coveralls.io api url', default='https://coveralls.io/api/v1/jobs')
     parser.add_argument('--base_dir', '-b', help='project root directory', default='.')
-    parser.add_argument('--data_file', '-d', help='coverage file name', default='.coverage')
-    parser.add_argument('--config_file', '-c', help='coverage config file name', default='.coveragerc')
+    parser.add_argument('--data_file', '-d', help='coverage file name', default=None)
+    parser.add_argument('--config_file', '-c', help='coverage config file name', default=None)
     parser.add_argument('--coveralls_yaml', '-y', help='coveralls yaml file name', default='.coveralls.yml')
-    parser.add_argument('--ignore-errors', '-i', help='gnore errors while reading source files', action='store_true', default=False)
+    parser.add_argument('--ignore-errors', '-i', help='ignore errors while reading source files', action='store_true', default=False)
+    parser.add_argument('--merge_file', '-m', help='json file containing coverage data to be merged (for merging javascript coverage)', default=None)
+    parser.add_argument('--nogit', help='do not gather git repo info', action='store_true', default=False)
     args = parser.parse_args()
     args.base_dir = os.path.abspath(args.base_dir)
-    args.data_file = os.path.join(args.base_dir, args.data_file)
-    args.config_file = os.path.join(args.base_dir, args.config_file)
+    args.data_file = os.path.join(args.base_dir, args.data_file) if args.data_file else None
+    args.config_file = os.path.join(args.base_dir, args.config_file) if args.config_file else True
     args.coveralls_yaml = os.path.join(args.base_dir, args.coveralls_yaml)
+    args.merge_file = os.path.join(args.base_dir, args.merge_file) if args.merge_file else None
     yml = {}
     try:
         with open(args.coveralls_yaml, 'r') as fp:
@@ -66,12 +71,13 @@ def parse_args():
     args.repo_token = yml.get('repo_token', os.environ.get('COVERALLS_REPO_TOKEN', ''))
     args.service_name = yml.get('service_name', 'travis-ci')
     args.service_job_id = os.environ.get('TRAVIS_JOB_ID', '')
+    args.parallel = yml.get('parallel', os.environ.get('COVERALLS_PARALLEL', False))
     return args
 
 
 def wear(args=None):
     from coveralls.control import coveralls
-    from coveralls.repository import gitrepo
+    from coveralls.repository import repo
     from coveralls.api import post
     import logging
     logging.basicConfig(level=logging.INFO)
@@ -84,8 +90,9 @@ def wear(args=None):
         repo_token=args.repo_token,
         service_job_id=args.service_job_id,
         service_name=args.service_name,
-        git=gitrepo(args.base_dir),
-        source_files=coverage.coveralls(args.base_dir, ignore_errors=args.ignore_errors),
+        git=repo(args.base_dir) if not args.nogit else {},
+        source_files=coverage.coveralls(args.base_dir, ignore_errors=args.ignore_errors, merge_file=args.merge_file),
+        parallel=args.parallel,
     )
     logger.info(response.status_code)
     logger.info(response.text)
